@@ -236,6 +236,20 @@ impl<'i, 't> Parser<'i, 't> {
         self.tokenizer.seen_var_functions()
     }
 
+    /// Start looking for viewport percentage lengths. (See the `seen_viewport_percentages`
+    /// method.)
+    #[inline]
+    pub fn look_for_viewport_percentages(&mut self) {
+        self.tokenizer.look_for_viewport_percentages()
+    }
+
+    /// Return whether a `vh`, `vw`, `vmin`, or `vmax` dimension has been seen by the tokenizer
+    /// since `look_for_viewport_percentages` was called, and stop looking.
+    #[inline]
+    pub fn seen_viewport_percentages(&mut self) -> bool {
+        self.tokenizer.seen_viewport_percentages()
+    }
+
     /// Execute the given closure, passing it the parser.
     /// If the result (returned unchanged) is `Err`,
     /// the internal state of the parser  (including position within the input)
